//===============================================================================
// Microsoft patterns & practices
// Web Client Software Factory
//===============================================================================
// Copyright  Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//===============================================================================
// The example companies, organizations, products, domain names,
// e-mail addresses, logos, people, places, and events depicted
// herein are fictitious.  No association with any real company,
// organization, product, domain name, email address, logo, person,
// places, or events is intended or should be inferred.
//===============================================================================

using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.CompositeWeb;
using SistemaBancario.Cliente.Entities;
using Microsoft.Practices.PageFlow;
using SistemaBancario.Cliente.PageFlows;

namespace SistemaBancario.Cliente
{
    public class ClienteController
    {
        static List<ClienteEntity> clientes = new List<ClienteEntity>();
        static int proximoId = 1;
        private IPageFlow _clientesPageFlow;
        private IPageFlowProvider _pageFlowProvider;

        static ClienteController()
        {
            clientes.Add(new ClienteEntity(proximoId++, "Monique Monteiro", "1234567890"));
            clientes.Add(new ClienteEntity(proximoId++, "José da Silva", "989898989"));
            clientes.Add(new ClienteEntity(proximoId++, "Maria da Silva", "384384234"));
        }

        public ClienteController([ProviderDependency(typeof (PageFlowDirectory))] IPageFlowProvider pageFlowProvider)
        {
            _pageFlowProvider = pageFlowProvider;
        }

        protected IPageFlow CadastrarClientePageFlow
        {
            get
            {
                if (this._clientesPageFlow == null)
                {
                    _clientesPageFlow = _pageFlowProvider.GetPageFlow(typeof(CadastroClientePageFlow));
                }
                return _clientesPageFlow;
            }
        }

        public virtual ClienteEntity ClienteAtual
        {
            get
            {
                if (CadastrarClientePageFlow.UserData.Contains("Cliente"))
                {
                    return CadastrarClientePageFlow.UserData["Cliente"] as ClienteEntity;
                }
                return null;
            }
            private set
            {
                CadastrarClientePageFlow.UserData["Cliente"] = value;                
            }
        }

        public void IniciarCadastroCliente()
        {
            CadastrarClientePageFlow.Start();
            ClienteAtual = null;
            CadastrarClientePageFlow.SetCurrentPage("CadastroCliente");
            CadastrarClientePageFlow.RedirectToCurrentPage();
        }

        public void SubmeterCadastroCliente(ClienteEntity cliente)
        {
            ClienteAtual = cliente;
            CadastrarClientePageFlow.Next();
        }

        public void CancelarCadastroCliente()
        {
            ClienteAtual = null;
            CadastrarClientePageFlow.Abort(true);
        }

        public void ConfirmarCadastroCliente()
        {
            CadastrarCliente(ClienteAtual);
            CadastrarClientePageFlow.Navigate("ConfirmarCadastro");
            CadastrarClientePageFlow.Complete();
            ClienteAtual = null;
        }

        public void CorrigirCadastroCliente()
        {
            CadastrarClientePageFlow.Navigate("CorrigirDados");
        }

        public IList<ClienteEntity> ListarClientes()
        {
            return clientes;
        }

        public void ExcluirCliente(ClienteEntity cliente)
        {
            clientes.Remove(cliente);
        }

        public void AtualizarCliente(ClienteEntity cliente)
        {
            clientes.Remove(cliente);
            clientes.Add(cliente);
        }

        private void CadastrarCliente(ClienteEntity cliente)
        {
            cliente.Id = proximoId++;
            clientes.Add(cliente);            
        }

    }
}
